@@ -367,7 +367,7 @@ macro_rules! add_conv_impl{
                             shifts.push(simd);
                         }
 
-                        let scalar_len = conv_len + 1; // + 1 due to rounding of odd numbers
+                        let scalar_len = conv_len + $reg::len(); // + $reg::len() due to rounding of odd numbers
                         let conv_len = conv_len as isize;
                         let mut i = 0;
                         for num in &mut dest[0..scalar_len] {
@@ -796,4 +796,4 @@ mod tests {
         let conv = conv.magnitude().unwrap();
         assert_eq_tol(mul.data(), conv.data(), 1e-4);
     }
-}
\ No newline at end of file
+}
